[![CI](https://github.com/ceesvandegriend/bstb/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/ceesvandegriend/bstb/actions/workflows/ci.yml)

# bstb / breastbone - Geocaching toolbox

N.B. `breastbone` is a random generated project name and has no special meaning.
